//
//  OgreTutorial2AppDelegate.m
//  OgreTutorial2
//
//  Created by Will Thimbleby on 1/29/11.
//  Copyright 2011 Will Thimbleby. All rights reserved.
//

#import "OgreTutorial2AppDelegate.h"
#import <Ogre/Ogre.h>

using namespace Ogre;

@implementation OgreTutorial2AppDelegate

- (void)applicationDidFinishLaunching:(NSNotification *)notification
{
	std::string mResourcePath = [[[NSBundle mainBundle] resourcePath]
        cStringUsingEncoding:NSUTF8StringEncoding];
	
	// Create a new root object with the correct paths
	Root *mRoot = new Root(mResourcePath + "/plugins.cfg", mResourcePath + "/ogre.cfg",
		mResourcePath + "/ogre.log");
	mRoot->setRenderSystem(mRoot->getAvailableRenderers().front());
	
	// Show a configure box and exit if user clicked cancel
	if(!mRoot->showConfigDialog())
		return;
	
	// Initialise
	RenderWindow *mWindow = mRoot->initialise(true);
	SceneManager *mSceneMgr = mRoot->createSceneManager(ST_GENERIC, "My scene manager");
    
	// Add resource locations
	ResourceGroupManager::getSingleton().addResourceLocation(mResourcePath,
        std::string("FileSystem"), ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
	ResourceGroupManager::getSingleton().initialiseAllResourceGroups();
	
	// Create the camera, node & attach camera
	Camera *mCamera = mSceneMgr->createCamera("My camera");
	SceneNode *camNode = mSceneMgr->getRootSceneNode()->createChildSceneNode();
	camNode->attachObject(mCamera);
	mWindow->addViewport(mCamera);
    
    // Create a light
    mSceneMgr->setAmbientLight(ColourValue(0, 0, 0));
    mSceneMgr->createLight("MainLight");
    
    // Add a object, give it it's own node
    SceneNode *objectNode = mSceneMgr->getRootSceneNode()->createChildSceneNode();
    Entity *knot = mSceneMgr->createEntity("knot", "knot.mesh");
    objectNode->attachObject(knot);
    objectNode->setPosition(Vector3(0, 0, -500));
}

@end
